project_structure: project_structure

View source: R/project_structure.R

project_structureR Documentation

project_structure

Description

Creates a project structure in the current working directory.

Usage

project_structure(.path = "", .template = "basic", .data_folder = TRUE)

Arguments

.path

A character vector containing the path to the project.

.template

Defaults to "basic". Character vector that can be used to choose user-defined templates that have been saved to "system.file/templates".

.data_folder

Logical. If TRUE, a folder of name 'data' with subdirectories 'raw' and 'clean' is created in the root folder of the current project.

Value

A character vector with the numeric variables.

Examples

-

janbrederecke/prepareD documentation built on Oct. 26, 2022, 8:06 p.m.