View source: R/project_structure.R
| project_structure | R Documentation |
Creates a project structure in the current working directory.
project_structure(.path = "", .template = "basic", .data_folder = TRUE)
.path |
A character vector containing the path to the project. |
.template |
Defaults to "basic". Character vector that can be used to choose user-defined templates that have been saved to "system.file/templates". |
.data_folder |
Logical. If TRUE, a folder of name 'data' with subdirectories 'raw' and 'clean' is created in the root folder of the current project. |
A character vector with the numeric variables.
-
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.